// MAT259 - 2D Frequency Matrix
// Author: Mert Toka (2017)
// Date: 2017-01-31
// 
// Description: Through this visualization, I am questioning whether film  
// adaptations of particular titles promote their printed counterparts? It 
// is commonnotion that an average audience of big budget productions later  
// being informed that the story is based on either fiction or nonfiction 
// books. I want to examine when this revelation kicks in and pushes people 
// to read books, and what kinds of parameters play an important role on this
// timeframe between movie popularity and book resurrection. 
// 
// Version: 2

Title titles[] = new Title[6];

// drawing parameters
float marginVert, marginHor, padding;
float titleWidth, titleHeight;

void setup() {
  fullScreen();
  //size(1280, 720);
  smooth(8);
  
  titles[0] = new Title("Orange is the New Black", 20);
  titles[1] = new Title("Game of Thrones", 0);
  titles[2] = new Title("Divergent", 200); 
  titles[3] = new Title("Hunger Games", 100);
  titles[4] = new Title("Maze Runner", 300);
  titles[5] = new Title("Twilight", 90); 
 
  colorMode(HSB, 360, 100, 100);
}

void draw() {
  background(isBlack ? 0 : 360);

  // In order to tweak colors
  titles[0].setHue(247, 54, 61);
  titles[1].setHue(223, 66, 73);
  titles[2].setHue(180, 54, 76); 
  titles[3].setHue(0, 0, 92);
  titles[4].setHue(26, 63, 96);
  titles[5].setHue(355, 63, 96); 

  // In order to tweak layout
  marginVert = 70;
  marginHor = 90;
  padding = 25;

  // Title drawing
  for (int i = 0; i < titles.length; i++) {
    pushMatrix();
    translate(marginHor+15+(titleWidth+padding)*i, marginVert+30);
    titles[i].draw();
    titles[i].drawLabel();
    popMatrix();
  }

  // Label Drawing
  drawLabels();
  
  // Draw Selection
  drawSelection();
}

void drawLabels(){
  float spacing = (height-2*marginVert)/((endYear-startYear+1)*12);
  fill(0,0, isBlack? 90 : 5,150);
  textAlign(LEFT, BOTTOM);
  textSize(21);
  text("Do Film Adaptations Promote Reading?", marginHor*3/5+10, marginVert/2+20);
  float w = textWidth("Do Film Adaptations Promote Reading?");
  textSize(10);
  text("Printed medium on left, motion picture on right", marginHor*3/5+20+w ,marginVert/2+20);
  textAlign(RIGHT, CENTER);
  text("Change Display Mode - 1,2,3", width-marginHor/2, marginVert/2+0);
  text("Log Scale - L", width-marginHor/2, marginVert/2+16);
  
  stroke(0,0,isBlack? 90 : 5, 150);
  line(marginHor*3/5 + 10, marginVert/2+30, width-marginHor/2, marginVert/2+30);
  
  textAlign(RIGHT, CENTER);
  for (int i = 0; i < titles[0].films.length; i++) {
    textSize(10);
    pushMatrix();
    translate(marginHor*3/5, i*12*spacing+marginVert+30);
    if(i+startYear <= endYear) text(i+startYear, 0, 0);
    popMatrix();
    
    stroke(0,0,isBlack? 90 : 5, isBlack? 28 : 18);
    line(marginHor*3/5 + 10, i*12*spacing+marginVert+30, width, i*12*spacing+marginVert+30);
    
    for (int j = 0; j < titles[0].films[0].length; j++) {
      textSize(10);
      pushMatrix();
      translate(marginHor*7/12, i*12*spacing+marginVert+30+j*spacing);
      if(i+startYear <= endYear) text( j%3 == 0 && j != 0 ? '-' : ' ', 0, 0);
      popMatrix();
    }
  }
  
  stroke(0,0,isBlack? 90 : 5, 150);
  line(marginHor*3/5 + 10, mouseY, width-marginHor/2, mouseY);
}

void drawSelection(){
  if(selection){
    noStroke();
    fill(0,0,50, 50);
    rect(0, initial_click.y, width, mouseY-initial_click.y);
  }
}